## Origin of example data

### Neurons

The example neurons provided are olfactory projection neurons of the DA1
glomerulus and were are from the Janelia hemibrain data set
(see [here](https://neuprint.janelia.org)) [1].

### Volumes
Example volumes provided are based on light microscopy images of the fruit
fly brain and were transformed into hemibrain space. See the
[`nat`](https://github.com/jefferis/nat) ecosystem for R.
In particular [`nat.jrcbrains`](https://github.com/jefferislab/nat.jrcbrains).

### References
[1] Louis K. Scheffer et al., bioRxiv. 2020. doi: https://doi.org/10.1101/2020.04.07.030213
A Connectome and Analysis of the Adult Drosophila Central Brain.
